@@ -3,10 +3,8 @@
 import urllib
 
 from pagador import settings
-from pagador.envio.models import SituacaoPedido
 from pagador.envio.requisicao import Enviar
-from pagador.retorno.registro import RegistrarPagamento
-from pagador_paypal.extensao.envio import ExpressCheckout, ExpressCheckoutDetails
+from pagador_paypal.extensao.envio import ExpressCheckout
 from pagador_paypal.extensao.seguranca import ParametrosPayPal
 
 
@@ -15,11 +13,6 @@ class TipoAck(object):
     Falha = "failure"
 
 
-# class Metodo(object):
-#     express_checkout = "SetExpressCheckout"
-#     checkout_details = "GetExpressCheckoutDetails"
-
-
 class EnviarPedido(Enviar):
     def __init__(self, pedido, dados, configuracao_pagamento):
         super(EnviarPedido, self).__init__(pedido, dados, configuracao_pagamento)
@@ -29,11 +22,15 @@ class EnviarPedido(Enviar):
             ExpressCheckout.cria_item_payment_request(item)
         self.exige_autenticacao = True
         self.processa_resposta = True
-        self.url = "https://api-3t.{}paypal.com/nvp".format("sandbox." if settings.DEBUG else "")
+        self.url = "https://api-3t.{}paypal.com/nvp".format(self.sandbox)
         self.grava_identificador = False
         self.headers = {"Content-Type": "application/x-www-form-urlencoded; charset=utf-8"}
         self.envio_por_querystring = True
 
+    @property
+    def sandbox(self):
+        return "sandbox." if (settings.ENVIRONMENT == "local" or settings.ENVIRONMENT == "development") else ""
+
     def gerar_dados_de_envio(self):
         notification_url = settings.PAYPAL_NOTIFICATION_URL.format(self.pedido.conta_id)
         parametros = ParametrosPayPal("paypal", id=self.pedido.conta_id)
@@ -72,7 +69,7 @@ class EnviarPedido(Enviar):
             self.define_valor_de_atributo_de_item(express_checkout, "AMT", indice, self.formatador.formata_decimal(item.preco_venda))
             self.define_valor_de_atributo_de_item(express_checkout, "QTY", indice, self.formatador.formata_decimal(item.quantidade))
             self.define_valor_de_atributo_de_item(express_checkout, "NUMBER", indice, item.sku[:127])
-            self.define_valor_de_atributo_de_item(express_checkout, "ITEMURL", indice, item.produto.get_absolute_url())
+            self.define_valor_de_atributo_de_item(express_checkout, "ITEMURL", indice, item.produto.get_absolute_url() or "")
         return express_checkout.to_dict()
 
     def define_valor_de_atributo_de_item(self, express_checkout, atributo, indice, valor):
@@ -93,7 +90,7 @@ class EnviarPedido(Enviar):
             content = urllib.unquote(content).decode('utf8')
             retorno = {par.split("=")[0].lower(): par.split("=")[1].lower() for par in content.split("&")}
         if "ack" in retorno and retorno["ack"] == TipoAck.Sucesso:
-            url = "https://www.{}paypal.com/cgi-bin/webscr?cmd=_express-checkout&token={}".format(("sandbox." if settings.DEBUG else ""), retorno["token"])
+            url = "https://www.{}paypal.com/cgi-bin/webscr?cmd=_express-checkout&token={}".format(self.sandbox, retorno["token"])
             return {"content": {"url": url}, "status": 200, "reenviar": False, "identificador": retorno["token"]}
 
         return {"content": retorno, "status": 500, "reenviar": False}
