@@ -41,9 +41,13 @@ class Registro(RegistroBase):
         self.envio_por_querystring = True
         self.sucesso = tipo == "success"
 
+    @property
+    def sandbox(self):
+        return "sandbox." if (settings.ENVIRONMENT == "local" or settings.ENVIRONMENT == "development") else ""
+
     @property
     def url(self):
-        return "https://api-3t.{}paypal.com/nvp".format("sandbox." if settings.DEBUG else "")
+        return "https://api-3t.{}paypal.com/nvp".format(self.sandbox)
 
     @property
     def pedido_numero(self):
